@@ -13,6 +13,7 @@ from . import product
 
 import records
 import json
+import requests
 
 __all__ = [
     'Customer',
@@ -191,8 +192,10 @@ class Customer(object):
         import time
         url = core.database_url(**FUPDB_CREDENTIALS)
         LOGS.logger.warn('last date {} de {}'.format(last_date, self.name))
+        LOGS.logger.debug("trace de {}".format(self.name))
         OK = False
         for i in range(3):
+            LOGS.logger.debug("essai {} de {}".format(i, self.name))
             if OK:
                 break
             try:
@@ -206,8 +209,8 @@ class Customer(object):
                     )
                 if response:
                     OK = True
-            except ValueError:
-                LOGS.logger.debug("essai {} de {} ERROR".format(i, self.name))
+            except requests.exceptions.ConnectTimeout:
+                LOGS.logger.debug("essai ERROR {} de {}".format(i, self.name))
                 time.sleep(60)
                 continue
         infos = response['content']
